==> apache-streampipes-0.68.0-incubating-source-release.zip: apache-streampipes-0.68.0-incubating/streampipes-pipeline-management/src/main/java/org/apache/streampipes/manager/matching/GroundingSelector.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

package org.apache.streampipes.manager.matching;

import org.apache.streampipes.model.base.InvocableStreamPipesEntity;
import org.apache.streampipes.model.base.NamedStreamPipesEntity;

import java.util.ArrayList;
import java.util.List;
import java.util.Set;

public abstract class GroundingSelector {

    protected NamedStreamPipesEntity source;
    protected Set<InvocableStreamPipesEntity> targets;

    public GroundingSelector(NamedStreamPipesEntity source, Set<InvocableStreamPipesEntity> targets) {
        this.source = source;
        this.targets = targets;
    }

    protected List<InvocableStreamPipesEntity> buildInvocables() {
        List<InvocableStreamPipesEntity> elements = new ArrayList<>();
        elements.add((InvocableStreamPipesEntity) source);
        elements.addAll(targets);

        return elements;
    }
}

==> apache-streampipes-0.70.0-incubating-source-release.zip: apache-streampipes-0.70.0-incubating/streampipes-pipeline-management/src/main/java/org/apache/streampipes/manager/matching/GroundingSelector.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

package org.apache.streampipes.manager.matching;

import org.apache.streampipes.model.base.InvocableStreamPipesEntity;
import org.apache.streampipes.model.base.NamedStreamPipesEntity;

import java.util.ArrayList;
import java.util.List;
import java.util.Set;

public abstract class GroundingSelector {

    protected NamedStreamPipesEntity source;
    protected Set<InvocableStreamPipesEntity> targets;

    public GroundingSelector(NamedStreamPipesEntity source,
                             Set<InvocableStreamPipesEntity> targets) {
        this.source = source;
        this.targets = targets;
    }

    protected List<InvocableStreamPipesEntity> buildInvocables() {
        List<InvocableStreamPipesEntity> elements = new ArrayList<>();
        elements.add((InvocableStreamPipesEntity) source);
        elements.addAll(targets);

        return elements;
    }
}
